@@ -930,7 +930,7 @@ def plot_hists_root(hists, options):
             objects['pads'] = divide_canvas(canvas, options.ratio_fraction)
             objects['pads'][0].cd()
         else:
-            hists = make_ratio_hists(hists, options)
+            hists = make_ratio_hists(hists, options, options.ratio - 1)
             isTGraph = True
     if options.xerr:
         ROOT.gStyle.SetErrorX()
@@ -1005,6 +1005,9 @@ def plot_hists_root(hists, options):
         objects['pads'][1].cd()
         objects['ratio_multigraph'] = plot_ratio_root(
             hists, roothist.GetXaxis().GetTitle(), options)
+        xmin = hists[0].xedges[0]
+        xmax = hists[0].xedges[-1]
+        objects['ratio_multigraph'].GetXaxis().SetRangeUser(xmin, xmax)
         objects['pads'][0].cd()
     if options.logx:
         for pad in objects['pads']:
@@ -1037,7 +1040,7 @@ def plot_hists_mpl(hists, options):
             axes = objects['axes'][0]
             fig.sca(axes)
         else:
-            hists = make_ratio_hists(hists, options)
+            hists = make_ratio_hists(hists, options, options.ratio - 1)
     refhist = hists[0]
     if refhist is None:
         refhist = hists[1]
@@ -1415,6 +1418,7 @@ def prep_first_draw(hist, histmax, options):
         hist.SetMaximum(options.ymax)
     if options.ratio:
         if options.split:
+            hist.Draw()
             hist.GetXaxis().SetBinLabel(1, '') # Don't show tick labels
             hist.GetXaxis().SetTitle('')
             ## Avoid overlap of y-axis numbers by supressing zero
@@ -1462,13 +1466,13 @@ def divide_axes(fig, axes, ratio_fraction):
     plt.setp(upper_axes.get_xticklabels(), visible=False)
     return upper_axes, lower_axes
 
-def make_ratio_hists(hists, options):
-    denom = hists[options.ratio - 1]
+def make_ratio_hists(hists, options, ratio_index):
+    denom = hists[ratio_index]
     if options.efficiency:
         ratios = [hist.divide_wilson(denom) for hist in hists]
     else:
         ratios = [hist.divide(denom) for hist in hists]        
-    ratios[options.ratio - 1] = None
+    ratios[ratio_index] = None
     return ratios
 
 def plot_ratio_root(hists, xlabel, options):
@@ -1481,7 +1485,17 @@ def plot_ratio_root(hists, xlabel, options):
         ylabel = options.ratio_label % locals()
     multigraph = ROOT.TMultiGraph("ratio_multi",
                                   ";%s;%s" % (xlabel, ylabel))
-    for i, ratio_hist in enumerate(make_ratio_hists(hists, options)):
+    if options.stack and options.data:
+        numerator = hists[ratio_index]
+        hists = hists[:]
+        hists.pop(ratio_index)
+        denominator = hists[0]
+        for hist in hists[1:]:
+            denominator += hist
+        hists = [numerator, denominator]
+        ratio_index = 1
+    for i, ratio_hist in enumerate(make_ratio_hists(hists, options, 
+                                                    ratio_index)):
         if i == ratio_index:
             continue
         graph = ratio_hist.TGraph()
@@ -1501,7 +1515,17 @@ def plot_ratio_mpl(axes, hists, options):
     #### Plot the ratio of each hist in hists to the ratio_indexth hist.
     ratio_index = options.ratio - 1
     stack = HistStack()
-    for i, ratio_hist in enumerate(make_ratio_hists(hists, options)):
+    if options.stack and options.data:
+        numerator = hists[ratio_index]
+        hists = hists[:]
+        hists.pop(ratio_index)
+        denominator = hists[0]
+        for hist in hists[1:]:
+            denominator += hist
+        hists = [numerator, denominator]
+        ratio_index = 1
+    for i, ratio_hist in enumerate(make_ratio_hists(hists, options, 
+                                                    ratio_index)):
         if i == ratio_index:
             continue
         ratio_hist.y = [item or 0 for item in ratio_hist.y] ## Avoid gaps
